@@ -17,7 +17,7 @@
 
 #include "textedit.h"
 #include <QDesktopServices>
-#include <QProcess>
+//#include <QProcess>
 #include <QToolTip>
 #include <QTimer>
 #include <QTextBlock>
@@ -963,7 +963,7 @@ void TextEdit::mouseReleaseEvent (QMouseEvent *e)
             url = QUrl::fromUserInput (str, "/", QUrl::AssumeLocalFile);
         /* QDesktopServices::openUrl() may resort to "xdg-open", which isn't
            the best choice. "gio" is always reliable, so we check it first. */
-        if (!QProcess::startDetached ("gio", QStringList() << "open" << url.toString()))
+        //if (!QProcess::startDetached ("gio", QStringList() << "open" << url.toString()))
             QDesktopServices::openUrl (url);
     }
     pressPoint_ = QPoint();
